# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from importlib import import_module
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from freeclimb.models.add_to_conference_notification_webhook import (
        AddToConferenceNotificationWebhook,
    )
    from freeclimb.models.add_to_queue_notification_webhook import (
        AddToQueueNotificationWebhook,
    )
    from freeclimb.models.call_control_webhook import CallControlWebhook
    from freeclimb.models.call_status_webhook import CallStatusWebhook
    from freeclimb.models.conference_recording_status_webhook import (
        ConferenceRecordingStatusWebhook,
    )
    from freeclimb.models.conference_status_webhook import ConferenceStatusWebhook
    from freeclimb.models.create_conference_webhook import CreateConferenceWebhook
    from freeclimb.models.dequeue_webhook import DequeueWebhook
    from freeclimb.models.get_digits_webhook import GetDigitsWebhook
    from freeclimb.models.get_speech_webhook import GetSpeechWebhook
    from freeclimb.models.inbound_call_webhook import InboundCallWebhook
    from freeclimb.models.leave_conference_webhook import LeaveConferenceWebhook
    from freeclimb.models.machine_detected_webhook import MachineDetectedWebhook
    from freeclimb.models.message_delivery_webhook import MessageDeliveryWebhook
    from freeclimb.models.message_status_webhook import MessageStatusWebhook
    from freeclimb.models.out_dial_api_connect_webhook import OutDialApiConnectWebhook
    from freeclimb.models.out_dial_connect_webhook import OutDialConnectWebhook
    from freeclimb.models.out_dial_start_webhook import OutDialStartWebhook
    from freeclimb.models.queue_wait_webhook import QueueWaitWebhook
    from freeclimb.models.record_webhook import RecordWebhook
    from freeclimb.models.redirect_webhook import RedirectWebhook
    from freeclimb.models.remove_from_queue_notification_webhook import (
        RemoveFromQueueNotificationWebhook,
    )
    from freeclimb.models.transcribe_webhook import TranscribeWebhook


class Webhook(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    Webhook
    """  # noqa: E501

    request_type: Optional[StrictStr] = Field(
        default=None, description="Type of webhook request", alias="requestType"
    )

    __properties: ClassVar[List[str]] = ["requestType"]

    # JSON field name that stores the object type
    __discriminator_property_name: ClassVar[str] = "requestType"

    # discriminator mappings
    __discriminator_value_class_map: ClassVar[Dict[str, str]] = {
        "addToConferenceNotification": "AddToConferenceNotificationWebhook",
        "addToQueueNotification": "AddToQueueNotificationWebhook",
        "callControl": "CallControlWebhook",
        "callStatus": "CallStatusWebhook",
        "conferenceRecordingStatus": "ConferenceRecordingStatusWebhook",
        "conferenceStatus": "ConferenceStatusWebhook",
        "createConference": "CreateConferenceWebhook",
        "dequeue": "DequeueWebhook",
        "getDigits": "GetDigitsWebhook",
        "getSpeech": "GetSpeechWebhook",
        "inboundCall": "InboundCallWebhook",
        "leaveConference": "LeaveConferenceWebhook",
        "machineDetected": "MachineDetectedWebhook",
        "messageDelivery": "MessageDeliveryWebhook",
        "messageStatus": "MessageStatusWebhook",
        "outDialApiConnect": "OutDialApiConnectWebhook",
        "outDialConnect": "OutDialConnectWebhook",
        "outDialStart": "OutDialStartWebhook",
        "queueWait": "QueueWaitWebhook",
        "record": "RecordWebhook",
        "redirect": "RedirectWebhook",
        "removeFromQueueNotification": "RemoveFromQueueNotificationWebhook",
        "transcribe": "TranscribeWebhook",
    }

    @classmethod
    def get_discriminator_value(cls, obj: Dict[str, Any]) -> Optional[str]:
        """Returns the discriminator value (object type) of the data"""
        discriminator_value = obj[cls.__discriminator_property_name]
        if discriminator_value:
            return cls.__discriminator_value_class_map.get(discriminator_value)
        else:
            return None

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[
        Union[
            AddToConferenceNotificationWebhook,
            AddToQueueNotificationWebhook,
            CallControlWebhook,
            CallStatusWebhook,
            ConferenceRecordingStatusWebhook,
            ConferenceStatusWebhook,
            CreateConferenceWebhook,
            DequeueWebhook,
            GetDigitsWebhook,
            GetSpeechWebhook,
            InboundCallWebhook,
            LeaveConferenceWebhook,
            MachineDetectedWebhook,
            MessageDeliveryWebhook,
            MessageStatusWebhook,
            OutDialApiConnectWebhook,
            OutDialConnectWebhook,
            OutDialStartWebhook,
            QueueWaitWebhook,
            RecordWebhook,
            RedirectWebhook,
            RemoveFromQueueNotificationWebhook,
            TranscribeWebhook,
        ]
    ]:
        """Create an instance of Webhook from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Optional[
        Union[
            AddToConferenceNotificationWebhook,
            AddToQueueNotificationWebhook,
            CallControlWebhook,
            CallStatusWebhook,
            ConferenceRecordingStatusWebhook,
            ConferenceStatusWebhook,
            CreateConferenceWebhook,
            DequeueWebhook,
            GetDigitsWebhook,
            GetSpeechWebhook,
            InboundCallWebhook,
            LeaveConferenceWebhook,
            MachineDetectedWebhook,
            MessageDeliveryWebhook,
            MessageStatusWebhook,
            OutDialApiConnectWebhook,
            OutDialConnectWebhook,
            OutDialStartWebhook,
            QueueWaitWebhook,
            RecordWebhook,
            RedirectWebhook,
            RemoveFromQueueNotificationWebhook,
            TranscribeWebhook,
        ]
    ]:
        """Create an instance of Webhook from a dict"""
        # look up the object type based on discriminator mapping
        object_type = cls.get_discriminator_value(obj)
        if object_type == "AddToConferenceNotificationWebhook":
            return import_module(
                "freeclimb.models.add_to_conference_notification_webhook"
            ).AddToConferenceNotificationWebhook.from_dict(obj)
        if object_type == "AddToQueueNotificationWebhook":
            return import_module(
                "freeclimb.models.add_to_queue_notification_webhook"
            ).AddToQueueNotificationWebhook.from_dict(obj)
        if object_type == "CallControlWebhook":
            return import_module(
                "freeclimb.models.call_control_webhook"
            ).CallControlWebhook.from_dict(obj)
        if object_type == "CallStatusWebhook":
            return import_module(
                "freeclimb.models.call_status_webhook"
            ).CallStatusWebhook.from_dict(obj)
        if object_type == "ConferenceRecordingStatusWebhook":
            return import_module(
                "freeclimb.models.conference_recording_status_webhook"
            ).ConferenceRecordingStatusWebhook.from_dict(obj)
        if object_type == "ConferenceStatusWebhook":
            return import_module(
                "freeclimb.models.conference_status_webhook"
            ).ConferenceStatusWebhook.from_dict(obj)
        if object_type == "CreateConferenceWebhook":
            return import_module(
                "freeclimb.models.create_conference_webhook"
            ).CreateConferenceWebhook.from_dict(obj)
        if object_type == "DequeueWebhook":
            return import_module(
                "freeclimb.models.dequeue_webhook"
            ).DequeueWebhook.from_dict(obj)
        if object_type == "GetDigitsWebhook":
            return import_module(
                "freeclimb.models.get_digits_webhook"
            ).GetDigitsWebhook.from_dict(obj)
        if object_type == "GetSpeechWebhook":
            return import_module(
                "freeclimb.models.get_speech_webhook"
            ).GetSpeechWebhook.from_dict(obj)
        if object_type == "InboundCallWebhook":
            return import_module(
                "freeclimb.models.inbound_call_webhook"
            ).InboundCallWebhook.from_dict(obj)
        if object_type == "LeaveConferenceWebhook":
            return import_module(
                "freeclimb.models.leave_conference_webhook"
            ).LeaveConferenceWebhook.from_dict(obj)
        if object_type == "MachineDetectedWebhook":
            return import_module(
                "freeclimb.models.machine_detected_webhook"
            ).MachineDetectedWebhook.from_dict(obj)
        if object_type == "MessageDeliveryWebhook":
            return import_module(
                "freeclimb.models.message_delivery_webhook"
            ).MessageDeliveryWebhook.from_dict(obj)
        if object_type == "MessageStatusWebhook":
            return import_module(
                "freeclimb.models.message_status_webhook"
            ).MessageStatusWebhook.from_dict(obj)
        if object_type == "OutDialApiConnectWebhook":
            return import_module(
                "freeclimb.models.out_dial_api_connect_webhook"
            ).OutDialApiConnectWebhook.from_dict(obj)
        if object_type == "OutDialConnectWebhook":
            return import_module(
                "freeclimb.models.out_dial_connect_webhook"
            ).OutDialConnectWebhook.from_dict(obj)
        if object_type == "OutDialStartWebhook":
            return import_module(
                "freeclimb.models.out_dial_start_webhook"
            ).OutDialStartWebhook.from_dict(obj)
        if object_type == "QueueWaitWebhook":
            return import_module(
                "freeclimb.models.queue_wait_webhook"
            ).QueueWaitWebhook.from_dict(obj)
        if object_type == "RecordWebhook":
            return import_module(
                "freeclimb.models.record_webhook"
            ).RecordWebhook.from_dict(obj)
        if object_type == "RedirectWebhook":
            return import_module(
                "freeclimb.models.redirect_webhook"
            ).RedirectWebhook.from_dict(obj)
        if object_type == "RemoveFromQueueNotificationWebhook":
            return import_module(
                "freeclimb.models.remove_from_queue_notification_webhook"
            ).RemoveFromQueueNotificationWebhook.from_dict(obj)
        if object_type == "TranscribeWebhook":
            return import_module(
                "freeclimb.models.transcribe_webhook"
            ).TranscribeWebhook.from_dict(obj)

        raise ValueError(
            "Webhook failed to lookup discriminator value from "
            + json.dumps(obj)
            + ". Discriminator property name: "
            + cls.__discriminator_property_name
            + ", mapping: "
            + json.dumps(cls.__discriminator_value_class_map)
        )



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.incoming_number_result import IncomingNumberResult


class TestIncomingNumberResult(unittest.TestCase):
    """IncomingNumberResult unit test stubs"""

    def setUp(self):
        self.model = IncomingNumberResult()

    def test_uri(self):
        """Test IncomingNumberResult.uri"""

        self.model.uri = "TEST_STRING"
        assert self.model.uri == "TEST_STRING"

    def test_date_created(self):
        """Test IncomingNumberResult.date_created"""

        self.model.date_created = "TEST_STRING"
        assert self.model.date_created == "TEST_STRING"

    def test_date_updated(self):
        """Test IncomingNumberResult.date_updated"""

        self.model.date_updated = "TEST_STRING"
        assert self.model.date_updated == "TEST_STRING"

    def test_revision(self):
        """Test IncomingNumberResult.revision"""
        self.model.revision = 1
        assert self.model.revision == 1

    def test_capabilities(self):
        """Test IncomingNumberResult.capabilities"""
        object = freeclimb.models.capabilities.Capabilities(
            voice=True,
            sms=True,
            toll_free=True,
            ten_dlc=True,
            short_code=True,
        )
        self.model.capabilities = object
        assert self.model.capabilities == object

    def test_campaign_id(self):
        """Test IncomingNumberResult.campaign_id"""

        self.model.campaign_id = "TEST_STRING"
        assert self.model.campaign_id == "TEST_STRING"

    def test_phone_number_id(self):
        """Test IncomingNumberResult.phone_number_id"""

        self.model.phone_number_id = "TEST_STRING"
        assert self.model.phone_number_id == "TEST_STRING"

    def test_account_id(self):
        """Test IncomingNumberResult.account_id"""

        self.model.account_id = "TEST_STRING"
        assert self.model.account_id == "TEST_STRING"

    def test_application_id(self):
        """Test IncomingNumberResult.application_id"""

        self.model.application_id = "TEST_STRING"
        assert self.model.application_id == "TEST_STRING"

    def test_phone_number(self):
        """Test IncomingNumberResult.phone_number"""

        self.model.phone_number = "TEST_STRING"
        assert self.model.phone_number == "TEST_STRING"

    def test_alias(self):
        """Test IncomingNumberResult.alias"""

        self.model.alias = "TEST_STRING"
        assert self.model.alias == "TEST_STRING"

    def test_region(self):
        """Test IncomingNumberResult.region"""

        self.model.region = "TEST_STRING"
        assert self.model.region == "TEST_STRING"

    def test_country(self):
        """Test IncomingNumberResult.country"""

        self.model.country = "TEST_STRING"
        assert self.model.country == "TEST_STRING"

    def test_voice_enabled(self):
        """Test IncomingNumberResult.voice_enabled"""
        self.model.voice_enabled = False
        assert self.model.voice_enabled == False

    def test_sms_enabled(self):
        """Test IncomingNumberResult.sms_enabled"""
        self.model.sms_enabled = False
        assert self.model.sms_enabled == False

    def test_offnet(self):
        """Test IncomingNumberResult.offnet"""
        self.model.offnet = False
        assert self.model.offnet == False

    def test_tfn(self):
        """Test IncomingNumberResult.tfn"""
        object = freeclimb.models.tfn.TFN(
            campaign_id="",
        )
        self.model.tfn = object
        assert self.model.tfn == object


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.message_status import MessageStatus
from freeclimb.models.webhook import Webhook
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class MessageStatusWebhook(
    Webhook, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    An outbound SMS has changed status and the notificationUrl from the Sms command or Send an SMS request is being invoked. A PerCL response will be ignored.
    """  # noqa: E501

    request_type: Optional[StrictStr] = Field(
        default=None,
        description="Value will be messageStatus - An outbound SMS has changed status and the Sms command's notificationUrl is being invoked.",
        alias="requestType",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="Account ID associated with your account.",
        alias="accountId",
    )
    message_id: Optional[StrictStr] = Field(
        default=None,
        description="Unique ID for this message, generated by FreeClimb.",
        alias="messageId",
    )
    call_id: Optional[StrictStr] = Field(
        default=None,
        description="Unique ID for the Call in the context of which the Sms PerCL command was issued.",
        alias="callId",
    )
    var_from: Optional[StrictStr] = Field(
        default=None,
        description="aPhone number used to initiate the SMS message (in E.164 format).",
        alias="from",
    )
    to: Optional[StrictStr] = Field(
        default=None,
        description="Destination number of the SMS message (in E.164 format).",
    )
    text: Optional[StrictStr] = Field(
        default=None, description="Body of the SMS message."
    )
    direction: Optional[StrictStr] = Field(
        default=None,
        description="Value will be outbound to indicate an outgoing SMS from FreeClimb.",
    )
    application_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the application to which the destination number is assigned. May be null if the originating number is invalid in some way or is not registered to an application.",
        alias="applicationId",
    )
    status: Optional[MessageStatus] = None
    phone_number_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the destination phone number.",
        alias="phoneNumberId",
    )

    __properties: ClassVar[List[str]] = [
        "requestType",
        "accountId",
        "messageId",
        "callId",
        "from",
        "to",
        "text",
        "direction",
        "applicationId",
        "status",
        "phoneNumberId",
    ]

    @classmethod
    def deserialize(cls, payload: str) -> Optional[Self]:
        return cls.from_json(payload)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MessageStatusWebhook from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict["status"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MessageStatusWebhook from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "requestType": obj.get("requestType"),
                "accountId": obj.get("accountId"),
                "messageId": obj.get("messageId"),
                "callId": obj.get("callId"),
                "from": obj.get("from"),
                "to": obj.get("to"),
                "text": obj.get("text"),
                "direction": obj.get("direction"),
                "applicationId": obj.get("applicationId"),
                "status": obj.get("status"),
                "phoneNumberId": obj.get("phoneNumberId"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.update_call_request import UpdateCallRequest


class TestUpdateCallRequest(unittest.TestCase):
    """UpdateCallRequest unit test stubs"""

    def setUp(self):
        self.model = UpdateCallRequest(
            status=UpdateCallRequestStatus.CANCELED,
        )

    def test_status(self):
        """Test UpdateCallRequest.status"""
        self.model.status = UpdateCallRequestStatus.CANCELED
        assert self.model.status == UpdateCallRequestStatus.CANCELED
        self.model.status = UpdateCallRequestStatus.COMPLETED
        assert self.model.status == UpdateCallRequestStatus.COMPLETED


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.call_list import CallList


class TestCallList(unittest.TestCase):
    """CallList unit test stubs"""

    def setUp(self):
        self.model = CallList()

    def test_total(self):
        """Test CallList.total"""
        self.model.total = 1
        assert self.model.total == 1

    def test_start(self):
        """Test CallList.start"""
        self.model.start = 1
        assert self.model.start == 1

    def test_end(self):
        """Test CallList.end"""
        self.model.end = 1
        assert self.model.end == 1

    def test_page(self):
        """Test CallList.page"""
        self.model.page = 1
        assert self.model.page == 1

    def test_num_pages(self):
        """Test CallList.num_pages"""
        self.model.num_pages = 1
        assert self.model.num_pages == 1

    def test_page_size(self):
        """Test CallList.page_size"""
        self.model.page_size = 1
        assert self.model.page_size == 1

    def test_next_page_uri(self):
        """Test CallList.next_page_uri"""

        self.model.next_page_uri = "TEST_STRING"
        assert self.model.next_page_uri == "TEST_STRING"

    def test_calls(self):
        """Test CallList.calls"""
        testList = []
        self.model.calls = testList
        assert self.model.calls == testList


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from freeclimb.models.message_status import MessageStatus
from freeclimb.models.tfn import TFN
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class MessageResult(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    MessageResult
    """  # noqa: E501

    uri: Optional[StrictStr] = Field(
        default=None, description="The URI for this resource, relative to /apiserver."
    )
    date_created: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateCreated",
    )
    date_updated: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateUpdated",
    )
    revision: Optional[StrictInt] = Field(
        default=None,
        description="Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="String that uniquely identifies this account resource.",
        alias="accountId",
    )
    message_id: Optional[StrictStr] = Field(
        default=None,
        description="String that uniquely identifies this message resource",
        alias="messageId",
    )
    status: Optional[MessageStatus] = None
    var_from: Optional[StrictStr] = Field(
        default=None,
        description="Phone number in E.164 format that sent the message.",
        alias="from",
    )
    to: Optional[StrictStr] = Field(
        default=None,
        description="Phone number in E.164 format that received the message.",
    )
    text: Optional[StrictStr] = Field(default=None, description="Message contents")
    direction: Optional[StrictStr] = Field(
        default=None, description="Noting whether the message was inbound or outbound"
    )
    notification_url: Optional[StrictStr] = Field(
        default=None,
        description="URL invoked when message sent",
        alias="notificationUrl",
    )
    brand_id: Optional[StrictStr] = Field(
        default=None,
        description="The unique identifier for the brand associated with the message",
        alias="brandId",
    )
    campaign_id: Optional[StrictStr] = Field(
        default=None,
        description="The unique identifier for the campaign associated with the message",
        alias="campaignId",
    )
    segment_count: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None,
        description="The number of segments into which the message was split",
        alias="segmentCount",
    )
    media_urls: Optional[List[StrictStr]] = Field(
        default=None,
        description="an array of HTTP URLs which were attached this this message",
        alias="mediaUrls",
    )
    tfn: Optional[TFN] = None
    phone_number_id: Optional[StrictStr] = Field(
        default=None,
        description="String that uniquely identifies the phoneNumber resource used to send this Message",
        alias="phoneNumberId",
    )
    application_id: Optional[StrictStr] = Field(
        default=None,
        description="String that uniquely identifies the Application resource used to send this Message",
        alias="applicationId",
    )

    __properties: ClassVar[List[str]] = [
        "uri",
        "dateCreated",
        "dateUpdated",
        "revision",
        "accountId",
        "messageId",
        "status",
        "from",
        "to",
        "text",
        "direction",
        "notificationUrl",
        "brandId",
        "campaignId",
        "segmentCount",
        "mediaUrls",
        "tfn",
        "phoneNumberId",
        "applicationId",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MessageResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of tfn
        if self.tfn:
            _dict["tfn"] = self.tfn.to_dict()
        # set to None if account_id (nullable) is None
        # and model_fields_set contains the field
        if self.account_id is None and "account_id" in self.model_fields_set:
            _dict["accountId"] = None

        # set to None if message_id (nullable) is None
        # and model_fields_set contains the field
        if self.message_id is None and "message_id" in self.model_fields_set:
            _dict["messageId"] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict["status"] = None

        # set to None if var_from (nullable) is None
        # and model_fields_set contains the field
        if self.var_from is None and "var_from" in self.model_fields_set:
            _dict["from"] = None

        # set to None if to (nullable) is None
        # and model_fields_set contains the field
        if self.to is None and "to" in self.model_fields_set:
            _dict["to"] = None

        # set to None if text (nullable) is None
        # and model_fields_set contains the field
        if self.text is None and "text" in self.model_fields_set:
            _dict["text"] = None

        # set to None if direction (nullable) is None
        # and model_fields_set contains the field
        if self.direction is None and "direction" in self.model_fields_set:
            _dict["direction"] = None

        # set to None if notification_url (nullable) is None
        # and model_fields_set contains the field
        if (
            self.notification_url is None
            and "notification_url" in self.model_fields_set
        ):
            _dict["notificationUrl"] = None

        # set to None if brand_id (nullable) is None
        # and model_fields_set contains the field
        if self.brand_id is None and "brand_id" in self.model_fields_set:
            _dict["brandId"] = None

        # set to None if campaign_id (nullable) is None
        # and model_fields_set contains the field
        if self.campaign_id is None and "campaign_id" in self.model_fields_set:
            _dict["campaignId"] = None

        # set to None if segment_count (nullable) is None
        # and model_fields_set contains the field
        if self.segment_count is None and "segment_count" in self.model_fields_set:
            _dict["segmentCount"] = None

        # set to None if media_urls (nullable) is None
        # and model_fields_set contains the field
        if self.media_urls is None and "media_urls" in self.model_fields_set:
            _dict["mediaUrls"] = None

        # set to None if phone_number_id (nullable) is None
        # and model_fields_set contains the field
        if self.phone_number_id is None and "phone_number_id" in self.model_fields_set:
            _dict["phoneNumberId"] = None

        # set to None if application_id (nullable) is None
        # and model_fields_set contains the field
        if self.application_id is None and "application_id" in self.model_fields_set:
            _dict["applicationId"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MessageResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "uri": obj.get("uri"),
                "dateCreated": obj.get("dateCreated"),
                "dateUpdated": obj.get("dateUpdated"),
                "revision": obj.get("revision"),
                "accountId": obj.get("accountId"),
                "messageId": obj.get("messageId"),
                "status": obj.get("status"),
                "from": obj.get("from"),
                "to": obj.get("to"),
                "text": obj.get("text"),
                "direction": obj.get("direction"),
                "notificationUrl": obj.get("notificationUrl"),
                "brandId": obj.get("brandId"),
                "campaignId": obj.get("campaignId"),
                "segmentCount": obj.get("segmentCount"),
                "mediaUrls": obj.get("mediaUrls"),
                "tfn": (
                    TFN.from_dict(obj["tfn"]) if obj.get("tfn") is not None else None
                ),
                "phoneNumberId": obj.get("phoneNumberId"),
                "applicationId": obj.get("applicationId"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.out_dial import OutDial


class TestOutDial(unittest.TestCase):
    """OutDial unit test stubs"""

    def setUp(self):
        self.model = OutDial(
            action_url="TS",
            call_connect_url="TS",
            calling_number="TS",
            destination="TS",
        )

    def test_action_url(self):
        """Test OutDial.action_url"""
        self.model.action_url = "TEST_STRING"
        assert self.model.action_url == "TEST_STRING"

    def test_call_connect_url(self):
        """Test OutDial.call_connect_url"""
        self.model.call_connect_url = "TEST_STRING"
        assert self.model.call_connect_url == "TEST_STRING"

    def test_calling_number(self):
        """Test OutDial.calling_number"""

        self.model.calling_number = "TEST_STRING"
        assert self.model.calling_number == "TEST_STRING"

    def test_destination(self):
        """Test OutDial.destination"""

        self.model.destination = "TEST_STRING"
        assert self.model.destination == "TEST_STRING"

    def test_if_machine(self):
        """Test OutDial.if_machine"""
        self.model.if_machine = IfMachine.REDIRECT
        assert self.model.if_machine == IfMachine.REDIRECT
        self.model.if_machine = IfMachine.HANGUP
        assert self.model.if_machine == IfMachine.HANGUP

    def test_if_machine_url(self):
        """Test OutDial.if_machine_url"""
        self.model.if_machine_url = "TEST_STRING"
        assert self.model.if_machine_url == "TEST_STRING"

    def test_send_digits(self):
        """Test OutDial.send_digits"""

        self.model.send_digits = "TEST_STRING"
        assert self.model.send_digits == "TEST_STRING"

    def test_status_callback_url(self):
        """Test OutDial.status_callback_url"""
        self.model.status_callback_url = "TEST_STRING"
        assert self.model.status_callback_url == "TEST_STRING"

    def test_timeout(self):
        """Test OutDial.timeout"""
        self.model.timeout = 1
        assert self.model.timeout == 1

    def test_privacy_mode(self):
        """Test OutDial.privacy_mode"""
        self.model.privacy_mode = False
        assert self.model.privacy_mode == False


if __name__ == "__main__":
    unittest.main()
